package com.ruoyi.system.controller;

import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import javax.servlet.http.HttpServletResponse;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.common.core.web.page.TableDataInfo;
import org.springframework.web.bind.annotation.GetMapping;
import java.util.List;
import com.ruoyi.system.api.model.LoginUser;
import com.ruoyi.common.core.utils.ServletUtils;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.system.domain.SnTemplate;
import com.ruoyi.common.security.service.TokenService;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.service.ISnTemplateService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.core.web.controller.BaseController;

@RestController
@RequestMapping({ "/SnTemplate" })
public class SnTemplateController extends BaseController
{
    @Autowired
    private ISnTemplateService snTemplateService;
    @Autowired
    private TokenService tokenService;
    
    @GetMapping({ "/selectList" })
    public AjaxResult selectList(final SnTemplate snTemplate) {
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        if (!loginUser.getRoles().contains("admin")) {
            snTemplate.setStatus(Integer.valueOf(1));
        }
        snTemplate.getParams().put("excludeBack", 1);
        final List<SnTemplate> list = this.snTemplateService.selectSnTemplateList(snTemplate);
        return AjaxResult.success((Object)list);
    }
    
    @RequiresPermissions({ "system:SnTemplate:list" })
    @GetMapping({ "/list" })
    public TableDataInfo list(final SnTemplate snTemplate) {
        this.startPage();
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        if (!loginUser.getRoles().contains("admin")) {
            snTemplate.setStatus(Integer.valueOf(1));
        }
        Long userId = null;
        if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super")) {
            userId = loginUser.getUserid();
        }
        snTemplate.getParams().put("excludeBack", 1);
        if (userId != null) {
            snTemplate.getParams().put("userId", userId);
        }
        final List<SnTemplate> list = this.snTemplateService.selectSnTemplateList(snTemplate);
        return this.getDataTable((List)list);
    }
    
    @RequiresPermissions({ "system:SnTemplate:export" })
    @Log(title = "生态模板", businessType = BusinessType.EXPORT)
    @PostMapping({ "/export" })
    public void export(final HttpServletResponse response, final SnTemplate snTemplate) {
        final List<SnTemplate> list = this.snTemplateService.selectSnTemplateList(snTemplate);
        final ExcelUtil<SnTemplate> util = (ExcelUtil<SnTemplate>)new ExcelUtil((Class)SnTemplate.class);
        util.exportExcel(response, (List)list, "生态模板数据");
    }
    
    @RequiresPermissions({ "system:SnTemplate:query" })
    @GetMapping({ "/{templateId}" })
    public AjaxResult getInfo(@PathVariable("templateId") final Long templateId) {
        return this.success((Object)this.snTemplateService.selectSnTemplateByTemplateId(templateId));
    }
    
    @PostMapping({ "/countryNum" })
    public AjaxResult countryNum() {
        return this.snTemplateService.countryNum();
    }
    
    @RequiresPermissions({ "system:SnTemplate:add" })
    @Log(title = "生态模板", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody final SnTemplate snTemplate) {
        return this.toAjax(this.snTemplateService.insertSnTemplate(snTemplate));
    }
    
    @RequiresPermissions({ "system:SnTemplate:edit" })
    @Log(title = "生态模板", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody final SnTemplate snTemplate) {
        return this.toAjax(this.snTemplateService.updateSnTemplate(snTemplate));
    }
    
    @RequiresPermissions({ "system:SnTemplate:remove" })
    @Log(title = "生态模板", businessType = BusinessType.DELETE)
    @DeleteMapping({ "/{templateIds}" })
    public AjaxResult remove(@PathVariable final Long[] templateIds) {
        return this.snTemplateService.deleteSnTemplateByTemplateIds(templateIds);
    }
}
